=== modified file 'bzrlib/conflicts.py'
--- bzrlib/conflicts.py	2005-10-17 23:13:00 +0000
+++ bzrlib/conflicts.py	2005-10-28 15:39:25 +0000
@@ -27,7 +27,7 @@
 
 import bzrlib.status
 from bzrlib.branch import Branch
-from bzrlib.errors import BzrCommandError
+from bzrlib.errors import BzrCommandError, NotConflicted
 from bzrlib.commands import register_command
 from bzrlib.workingtree import CONFLICT_SUFFIXES
 
@@ -71,3 +71,30 @@
                     print "%s does not exist" % filename
                 else:
                     print "%s is not conflicted" % filename
+
+def restore(filename):
+    """\
+    Restore a conflicted file to the state it was in before merging.
+    Only text restoration supported at present.
+    """
+    conflicted = False
+    try:
+        os.rename(filename + ".THIS", filename)
+        conflicted = True
+    except OSError, e:
+        if e.errno != errno.ENOENT:
+            raise
+    try:
+        os.unlink(filename + ".BASE")
+        conflicted = True
+    except OSError, e:
+        if e.errno != errno.ENOENT:
+            raise
+    try:
+        os.unlink(filename + ".OTHER")
+        conflicted = True
+    except OSError, e:
+        if e.errno != errno.ENOENT:
+            raise
+    if not conflicted:
+        raise NotConflicted(filename)

=== modified file 'bzrlib/errors.py'
--- bzrlib/errors.py	2005-10-27 23:14:48 +0000
+++ bzrlib/errors.py	2005-10-28 15:39:25 +0000
@@ -400,3 +400,9 @@
     def __init__(self, graph):
         BzrNewError.__init__(self)
         self.graph = graph
+
+class NotConflicted(BzrNewError):
+    """File %(filename) is not conflicted."""
+    def __init__(self, filename):
+        BzrNewError.__init__(self)
+        self.filename = filename

=== modified file 'bzrlib/selftest/test_conflicts.py'
--- bzrlib/selftest/test_conflicts.py	2005-10-06 03:15:08 +0000
+++ bzrlib/selftest/test_conflicts.py	2005-10-28 15:39:25 +0000
@@ -20,7 +20,8 @@
 from bzrlib.selftest import TestCaseInTempDir
 from bzrlib.branch import Branch
 from bzrlib.commit import Commit
-
+from bzrlib.conflicts import restore
+from bzrlib.errors import NotConflicted
 
 # TODO: Test commit with some added, and added-but-missing files
 
@@ -29,16 +30,22 @@
     def test_conflicts(self):
         """Conflicts are detected properly"""
         b = Branch.initialize('.')
-        file('hello', 'w').write('hello world')
-        file('hello.BASE', 'w').write('hello world')
+        file('hello', 'w').write('hello world4')
+        file('hello.THIS', 'w').write('hello world2')
+        file('hello.BASE', 'w').write('hello world1')
+        file('hello.OTHER', 'w').write('hello world3')
         file('hello.sploo.BASE', 'w').write('yellow world')
+        file('hello.sploo.OTHER', 'w').write('yellow world2')
         tree = b.working_tree()
-        self.assertEqual(len(list(tree.list_files())), 3)
+        self.assertEqual(len(list(tree.list_files())), 6)
         conflicts = list(tree.iter_conflicts())
         self.assertEqual(len(conflicts), 2)
         assert 'hello' in conflicts
         assert 'hello.sploo' in conflicts
-        os.unlink('hello.BASE')
-        os.unlink('hello.sploo.BASE')
+        restore('hello')
+        restore('hello.sploo')
         self.assertEqual(len(list(tree.iter_conflicts())), 0)
-
+        self.assertFileEqual('hello world2', 'hello')
+        assert not os.path.lexists('hello.sploo')
+        self.assertRaises(NotConflicted, restore, 'hello')
+        self.assertRaises(NotConflicted, restore, 'hello.sploo')

